@@ -1,4 +1,4 @@
-from steinbock.classification.ilastik.ilastik import (
+from steinbock.classification.ilastik._ilastik import (
     list_ilastik_image_files,
     list_ilastik_crop_files,
     read_ilastik_image,
@@ -15,7 +15,6 @@ from steinbock.classification.ilastik.ilastik import (
     fix_ilastik_project_file_inplace,
 )
 
-
 __all__ = [
     "list_ilastik_image_files",
     "list_ilastik_crop_files",
